import 'package:flutter/material.dart';

import '../badges.dart';

class TBadgeStyle {
  /// Allows to set the shape to this [badgeContent].
  /// The default value is [BadgeShape.circle].
  final TBadgeShape shape;

  /// Allows to set border radius to this [badgeContent].
  /// The default value is [BorderRadius.zero].
  final BorderRadius borderRadius;

  /// Background color of the badge.
  /// If [gradient] is not null, this property will be ignored.
  final Color badgeColor;

  /// Allows to set border side to this [badgeContent].
  /// The default value is [BorderSide.none].
  final BorderSide borderSide;

  /// The size of the shadow below the badge.
  final double elevation;

  /// Background gradient color of the badge.
  /// Will be used over [badgeColor] if not null.
  final TBadgeGradient? badgeGradient;

  /// Background gradient color of the border badge.
  /// Will be used over [borderSide.color] if not null.
  final TBadgeGradient? borderGradient;

  /// Specifies padding for [badgeContent].
  /// The default value is EdgeInsets.all(5.0).
  final EdgeInsetsGeometry padding;

  const TBadgeStyle({
    this.shape = TBadgeShape.circle,
    this.borderRadius = BorderRadius.zero,
    this.badgeColor = Colors.red,
    this.borderSide = BorderSide.none,
    this.elevation = 2,
    this.badgeGradient,
    this.borderGradient,
    this.padding = const EdgeInsets.all(5.0),
  });
}
