import 'package:flutter/material.dart';
import 'dart:ui' as ui;

import '../t_badge_gradient.dart';
import '../t_badge_gradient_type.dart';
import 'calculation_utils.dart';

class GradientUtils {
  static Shader getGradientShader({
    required TBadgeGradient badgeGradient,
    required double width,
    required double height,
  }) {
    switch (badgeGradient.gradientType) {
      case TBadgeGradientType.linear:
        return ui.Gradient.linear(
          CalculationUtils.calculateOffset(
            alignment: badgeGradient.begin!,
            width: width,
            height: height,
          ),
          CalculationUtils.calculateOffset(
            alignment: badgeGradient.end!,
            width: width,
            height: height,
          ),
          badgeGradient.colors,
        );
      case TBadgeGradientType.radial:
        return ui.Gradient.radial(
          CalculationUtils.calculateOffset(
            alignment: badgeGradient.center!,
            width: width,
            height: height,
          ),
          width * badgeGradient.radius!,
          badgeGradient.colors,
        );
      case TBadgeGradientType.sweep:
        return ui.Gradient.sweep(
          CalculationUtils.calculateOffset(
            alignment: badgeGradient.center!,
            width: width,
            height: height,
          ),
          badgeGradient.colors,
        );
      default:
        return ui.Gradient.linear(const Offset(0, 0), const Offset(0, 0), [Colors.transparent]);
    }
  }
}
